Structs
- APIError
- API Error information structure
- APIRequest
- API Request structure for sending prompt and function information
- APIResponse
- API Response structure from the server
- APIResponse
Headers - API Response Headers struct
- APIUsage
- API Usage information detailing token counts
- User
Location - User location information for req api web search options
- WebSearch
Options