OpenAIClientState

Struct OpenAIClientState 

pub struct OpenAIClientState {
    pub prompt: VecDeque<Message>,
    pub client: OpenAIClient,
    pub entry_limit: Option<u64>,
}
Represents a client state with a prompt history.

Fields

prompt: VecDeque<Message>

Conversation history messages.

client: OpenAIClient

Reference to the OpenAIClient.

entry_limit: Option<u64>

Implementations

Source

impl<'a> OpenAIClientState

pub async fn add(&mut self, messages: Vec<Message>) -> &mut Self

Add messages to the conversation prompt.

Arguments
  • messages - A vector of messages to add.
Returns

A mutable reference to self.

pub async fn add_last(&mut self, messages: Vec<Message>) -> &mut Self

pub async fn set_entry_limit(&mut self, limit: u64) -> &mut Self

Set the maximum number of entries in the conversation prompt.

Arguments
  • limit - The maximum number of entries.
Returns

A mutable reference to self.

pub async fn clear(&mut self) -> &mut Self

Clear all messages from the conversation prompt.

Returns

A mutable reference to self.

pub async fn last(&mut self) -> Option<&Message>

Retrieve the last message in the prompt.

Returns

An Option containing a reference to the last Message.

pub async fn generate( &mut self, model: Option<&ModelConfig>, ) -> Result<GenerateResponse, ClientError>

Generate an AI response.

This method sends the prompt to the API and, upon successful response, adds the assistant’s message to the prompt.

Arguments
  • model - The model configuration.
Returns

An APIResult with the API response or a ClientError.

pub async fn generate_can_use_tool<F>( &mut self, model: Option<&ModelConfig>, show_call: Option<F>, ) -> Result<GenerateResponse, ClientError>
where F: Fn(&str, &Value),

Generate an AI response, possibly calling a tool.

If the API response includes a function call, it will run the corresponding tool.

Arguments
  • model - The model configuration.
  • show_call - Optional callback function to show the tool call.(eg, show_call("tool_name", "args"))
Returns

An APIResult with the API response or a ClientError.

pub async fn generate_use_tool<F>( &mut self, model: Option<&ModelConfig>, show_call: Option<F>, ) -> Result<GenerateResponse, ClientError>
where F: Fn(&str, &Value),

Generate an AI response while forcing the use of a specific tool.

If the response includes a function call, the specified tool will be executed

Arguments
  • model - The model configuration.
  • tool_name - The name of the tool to use.
  • show_call - Optional callback function to show the tool call.(eg, show_call("tool_name", "args"))
Returns

An APIResult with the API response or a ClientError.

pub async fn generate_with_tool<F>( &mut self, model: Option<&ModelConfig>, tool_name: &str, show_call: Option<F>, ) -> Result<GenerateResponse, ClientError>
where F: Fn(&str, &Value),

Generate an AI response while forcing the use of a specific tool.

If the response includes a function call, the specified tool will be executed.

Arguments
  • model - The model configuration.
  • tool_name - The name of the tool to use.
  • show_call - Optional callback function to show the tool call.(eg, show_call("tool_name", "args"))
Returns

An APIResult with the API response or a ClientError.

Source

impl<'a> OpenAIClientState

new api after v.1.4.0

pub async fn reasoning( &'a mut self, model: Option<&ModelConfig>, mode: &ToolMode, ) -> Result<ReasoningState<'a>, ClientError>