Module api

Module api 

Structs

APIError
API Error information structure
APIRequest
API Request structure for sending prompt and function information
APIResponse
API Response structure from the server
APIResponseHeaders
API Response Headers struct
APIUsage
API Usage information detailing token counts
UserLocation
User location information for req api web search options
WebSearchOptions